Remove mention of CDSChecker
[c11tester.git] / main.cc
diff --git a/main.cc b/main.cc
index 80ac52ac1995b9303d012a76ca434c00014be117..bcdafc482a5ff7de6111f64a4d0c824d9759af64 100644 (file)
--- a/main.cc
+++ b/main.cc
@@ -171,16 +171,16 @@ int main(int argc, char **argv)
        main_argv = argv;
 
        /*
* If this printf statement is removed, CDSChecker will fail on an
         * assert on some versions of glibc.  The first time printf is
         * called, it allocated internal buffers.  We can't easily snapshot
         * libc since we also use it.
         */
 
-       printf("CDSChecker\n"
-                                "Copyright (c) 2013 Regents of the University of California. All rights reserved.\n"
+       printf("C11Fuzzer\n"
+                                "Copyright (c) 2013 and 2019 Regents of the University of California. All rights reserved.\n"
                                 "Distributed under the GPLv2\n"
-                                "Written by Brian Norris and Brian Demsky\n\n");
+                                "Written by Weiyu Luo, Brian Norris, and Brian Demsky\n\n");
 
        /* Configure output redirection for the model-checker */
        redirect_output();
@@ -171,16 +171,16 @@ int main(int argc, char **argv)
 
        /*
-        * If this printf statement is removed, CDSChecker will fail on an
+        * If this printf statement is removed, C11Fuzzer will fail on an
         * assert on some versions of glibc.  The first time printf is
         * called, it allocated internal buffers.  We can't easily snapshot